@@ -1,12 +1,12 @@
 #
-#   Copyright 2007-2019 by the individuals mentioned in the source code history
+#   Copyright 2007-2021 by the individuals mentioned in the source code history
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
 #   You may obtain a copy of the License at
-# 
+#
 #        http://www.apache.org/licenses/LICENSE-2.0
-# 
+#
 #   Unless required by applicable law or agreed to in writing, software
 #   distributed under the License is distributed on an "AS IS" BASIS,
 #   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -24,6 +24,15 @@ mxOption <- function(model=NULL, key=NULL, value, reset = FALSE) {
 	if (is.null(model) && reset) {
 		return(invisible(mxSetDefaultOptions()))
 	}
+	optionsNames <- names(getOption('mxOptions'))
+	match <- grep(paste("^", key, "$", sep = ""), optionsNames,
+		ignore.case=TRUE)
+	if(length(match) == 0) {
+		stop(paste("argument 'key' is the character string",
+			omxQuotes(key), "and cannot be found in",
+			"getOption('mxOptions')"))
+	}
+	key <- optionsNames[[match]] # repair capitalization
 	if (missing(value)) {
 		if (length(model) && !is.null(model@options[[key]])) {
 			return(model@options[[key]])
@@ -62,16 +71,8 @@ mxOption <- function(model=NULL, key=NULL, value, reset = FALSE) {
 		model@options <- list()
 		return(model)
 	}
-	optionsNames <- names(getOption('mxOptions'))
-	match <- grep(paste("^", key, "$", sep = ""), optionsNames,
-		ignore.case=TRUE)
-	if(length(match) == 0) {
-		stop(paste("argument 'key' is the character string",
-			omxQuotes(key), "and cannot be found in",
-			"getOption('mxOptions')"))
-	}
-	key <- optionsNames[[match]] # repair capitalization
-	if (key == "Default optimizer" || key == "Gradient algorithm" || key == "Gradient iterations") {
+	if (key == "Default optimizer" || key == "Gradient algorithm" ||
+        key == "Gradient iterations" || key == "Gradient step size") {
 		stop(paste(omxQuotes(key), " is a global option and cannot be set on models.\n",
 		"To change ", omxQuotes(key) ," globally, use, e.g.:\n",
 		"mxOption(NULL, '", key, "', '", value,"')", sep = ""))
@@ -141,14 +142,14 @@ npsolOptions <- list(
 )
 
 checkpointOptions <- list(
-	"Checkpoint Directory" = ".", 
+	"Checkpoint Directory" = ".",
 	"Checkpoint Prefix" = "",
 	"Checkpoint Units" = "iterations",
 	"Checkpoint Count" = 1,
         "Checkpoint Fullpath" = "",
-	"Socket Server" = "", 
+	"Socket Server" = "",
 	"Socket Port" = 8080,
-	"Socket Units" = "minutes", 
+	"Socket Units" = "minutes",
 	"Socket Count" = c("minutes" = 0.08, "iterations" = 1)
 )
 
@@ -197,25 +198,24 @@ imxGetNumThreads <- function() {
 		if (!is.na(thrlimit)) {
 			return(thrlimit)
 		} else {
-			detect <- omxDetectCores()
-			if(is.na(detect)) detect <- 1L
-					# Due to demand by CRAN maintainers, we default to 2 cores
-					# when OMP_NUM_THREADS is not set. This seems like a bad
-					# policy to the OpenMx team, but we have no choice.
-			else detect <- 2L
-			return(detect)
+      # CRAN allows use of up to 2 CPUs when OMP_NUM_THREADS is not
+      # set, but for some reason some examples finish too fast as if
+      # we're using more than 2 CPUs:
+      #
+      # "Examples with CPU time > 2.5 times elapsed time"
+      #
+      # To work around this issue, never use more than 1 CPU when
+      # OMP_NUM_THREADS is not set.
+			return(1L)
 		}
 	}
 }
 
-generateOptionsList <- function(model, constraints, useOptimizer) {
+generateOptionsList <- function(model, useOptimizer) {
 	input <- list()
 	if (!is.null(model)) {
 		input <- model@options
-		if (is.null(input[["Standard Errors"]]) && constraints > 0 && imxHasWLS(model)){
-			input[["Standard Errors"]] <- "No"
-		}
-		if( !is.null(input[["UsePPML"]]) 
+		if( !is.null(input[["UsePPML"]])
 		   && (input[["UsePPML"]] == "PartialSolved" || input[["UsePPML"]] == "Split") ) {
 			input[["Calculate Hessian"]] <- "No"
 			input[["Hessian"]] <- "No"
@@ -264,7 +264,7 @@ combineDefaultOptions <- function(input) {
   #overwritten by the defaults:
   namesHandled <- c( names(temp), "Major iterations" )
 	if(sum( !(names(input) %in% namesHandled) )>0){
-    options[names(input)[!(names(input) %in% namesHandled)]] <- 
+    options[names(input)[!(names(input) %in% namesHandled)]] <-
       input[names(input)[!(names(input) %in% namesHandled)]]
   }
 	return(options)
@@ -272,15 +272,15 @@ combineDefaultOptions <- function(input) {
 
 
 ##' imxAutoOptionValue
-##' 
+##'
 ##' Convert "Auto" placeholders in global mxOptions to actual default values.
-##' 
+##'
 ##' This is an internal function exported for documentation purposes.
 ##' Its primary purpose is to convert the on-load value of "Auto"to
 ##' valid values for \link{mxOption}s \sQuote{Gradient step size},
-##' \sQuote{Gradient iterations}, and 
+##' \sQuote{Gradient iterations}, and
 ##' \sQuote{Function precision}--respectively, 1.0e-7, 1L, and 1e-14.
-##' 
+##'
 ##' @param optionName Character string naming the \link{mxOption} for which a numeric or integer value is wanted.
 ##' @param optionList List of options; defaults to list of global \link{mxOption}s.
 ##' imxAutoOptionValue
@@ -288,7 +288,7 @@ imxAutoOptionValue <- function(optionName, optionList=options()$mxOption){
 	#First, check to see if the option already has a valid value (possibly in string form), and if so, return that:
 	numcast <- try(suppressWarnings(as.numeric(optionList[[optionName]])),silent=TRUE)
 	if(!length(numcast)){
-		#NULL numcast is most likely to result from either (1) misspelled optionName, 
+		#NULL numcast is most likely to result from either (1) misspelled optionName,
 		#or (2) user providing non-default value for optionList that lacks an element named optionName.
 		#Throwing an error seems the best behavior in this case.
 		stop(paste("extracting element '",optionName,"' from argument 'optionList' resulted in NULL"),sep="")
@@ -300,7 +300,7 @@ imxAutoOptionValue <- function(optionName, optionList=options()$mxOption){
 		return(numcast)
 	}
 	#Otherwise, if the current value is a string and can be matched to "Auto",
-	#convert to default numerical value for the three motivating cases: 
+	#convert to default numerical value for the three motivating cases:
 	else{
 		if(length(grep(pattern="Auto",x=optionList[[optionName]],ignore.case=T))){
 			if(optionName=="Gradient step size"){return(1.0e-7)}
@@ -310,4 +310,3 @@ imxAutoOptionValue <- function(optionName, optionList=options()$mxOption){
 		else{stop(paste("found unrecognized character string '",optionList[[optionName]],"' as value for mxOption '",optionName,"' in argument 'optionList'",sep=""))}
 	}
 }
-
