@@ -355,7 +355,12 @@ computeOptimizationStatistics <- function(model, flatModel, numStats, saturatedD
 		}
 		# number of variables
 		if(datalist[[1]]@type != 'raw'){
-			nvar <- dim(datalist[[1]]@observed)[2]
+			if(datalist[[1]]@type == 'none'){
+				nvar <- nrow(datalist[[1]]@observedStats$cov)
+			}
+			else{
+				nvar <- dim(datalist[[1]]@observed)[2]
+			}
 		} else if( length(expectations) == 1 ) {
 			nvar <- length(expectations[[1]]@dims)
 		} else {
@@ -1149,7 +1154,7 @@ logLik.MxModel <- function(object, ...) {
   	for(i in 1:length(M_need_pos)){
   		Mpos[1,M_need_pos[i]] <- out$name[j] <- paste(
   			model@name,".M[1,",M_need_pos[i],"]",sep="")
-  		if(!all.na(model_M$labels)){
+  		if(!is.null(model_M$labels) && !all.na(model_M$labels)){
   			out$label[j] <- model_M$labels[1,M_need_pos[i]]
   		}
   		out$matrix[j] <- "M"
@@ -1300,13 +1305,13 @@ mxStandardizeRAMpaths <- function(model, SE=FALSE, cov=NULL){
   }
   #Check if single-group model uses RAM expectation, and proceed if so:
   if(length(model@submodels)==0){
-    if(class(model$expectation)!="MxExpectationRAM"){stop(paste("model '",model@name,"' does not use RAM expectation",sep=""))}
+    if (!inherits(model$expectation, "MxExpectationRAM")) {stop(paste("model '",model@name,"' does not use RAM expectation",sep=""))}
     return(.mxStandardizeRAMhelper(model=model,SE=SE,ParamsCov=covParam))
   }
   #Handle multi-group model:
   if(length(model@submodels)>0){
   	out <- NULL
-  	if(class(model$expectation)=="MxExpectationRAM"){
+  	if (inherits(model$expectation, "MxExpectationRAM")) {
   		out <- list(.mxStandardizeRAMhelper(model=model,SE=SE,ParamsCov=covParam,ignoreSubmodels=TRUE))
   		names(out)[1] <- model@name
   	}
@@ -1345,7 +1350,7 @@ mxBootstrapStdizeRAMpaths <- function(model, bq=c(.25,.75), method=c('bcbci','qu
 	if(!is(model, "MxModel")) {
 		stop("'model' argument must be a MxModel object")
 	}
-	if(!length(model@expectation) || class(model@expectation) != "MxExpectationRAM"){
+	if(!length(model@expectation) || !inherits(model@expectation, "MxExpectationRAM")) {
 		msg <- paste(
 			"MxModel ",omxQuotes(model@name),
 			" does not use RAM expectation\n(to use mxBootstrapStdizeRAMpaths() on a RAM submodel, run the function directly on that submodel",sep="")
