@@ -1,5 +1,5 @@
-#ifndef _DMVNORM_H_
-#define _DMVNORM_H_
+#ifndef u_DMVNORM_H_
+#define u_DMVNORM_H_
 
 double
 dmvnorm(int dim, double *loc, double *mean, double *sigma);
