@@ -1,5 +1,5 @@
 /*
- *  Copyright 2007-2019 by the individuals mentioned in the source code history
+ *  Copyright 2007-2021 by the individuals mentioned in the source code history
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -15,8 +15,8 @@
  *
  */
 
-#ifndef _OMXDEFINES_H_
-#define _OMXDEFINES_H_
+#ifndef u_OMXDEFINES_H_
+#define u_OMXDEFINES_H_
 
 #include <Rcpp.h>
 using namespace Rcpp;
@@ -45,7 +45,7 @@ static inline bool strEQ(const char *s1, const char *s2) { return strcmp(s1,s2)=
 
 #define EIGEN_NO_DEBUG 1
 //#define EIGEN_DONT_PARALLELIZE
-#define  _OpenMx_Compilation_ 1  // work around bug in Eigen 3.2.5
+#define  u_OpenMx_Compilation_ 1  // work around bug in Eigen 3.2.5
 #define EIGEN_DEFAULT_DENSE_INDEX_TYPE int   // default is 8 but 4 bytes is plenty for us
 
 #ifdef OMX_BOUNDS_CHECK
@@ -67,7 +67,7 @@ static inline bool strEQ(const char *s1, const char *s2) { return strcmp(s1,s2)=
 #ifdef OMX_BOUNDS_CHECK
 #define EIGEN_INITIALIZE_MATRICES_BY_NAN
 #undef EIGEN_NO_DEBUG
-//#define _GLIBCXX_DEBUG  // but gives link errors without -D_GLIBCXX_DEBUG on command line
+//#define u_GLIBCXX_DEBUG  // but gives link errors without -D_GLIBCXX_DEBUG on command line
 #endif // OMX_BOUNDS_CHECK
 
 #ifdef DEBUGMX_ROWS
@@ -118,6 +118,7 @@ enum FitStatisticUnits {
 	FIT_UNITS_MINUS2LL,
 	FIT_UNITS_SQUARED_RESIDUAL,
 	FIT_UNITS_SQUARED_RESIDUAL_CHISQ,  // full weight matrix
+	FIT_UNITS_ANY,
 };
 
 #define GRADIENT_FUDGE_FACTOR(x) (pow(10.0,x))
@@ -230,7 +231,12 @@ static inline int omp_get_thread_num() { return 0; }
 static inline int omp_get_num_threads(void) { return 1; }
 #endif
 
+#include <stan/math/version.hpp>
+#if STAN_MATH_MAJOR >= 4
+#include <stan/math/prim/fun/Eigen.hpp>
+#else
 #include <stan/math/prim/mat/fun/Eigen.hpp>
+#endif
 #include <Eigen/Core>
 
 // Refactor as a single split function that pulls out all 3 parts
@@ -396,13 +402,76 @@ void subsetRows(const Eigen::MatrixBase<T1> &in, T2 includeTest,
 	}
 }
 
-template<typename _MatrixType, int _UpLo = Eigen::Lower>
-class SimpCholesky : public Eigen::LDLT<_MatrixType, _UpLo> {
+template <typename T1, typename T2, typename T3, typename T4, typename T5>
+void partitionCovariance(const Eigen::MatrixBase<T1> &gcov,
+		     T2 filterTest,
+		     Eigen::MatrixBase<T3> &v11,
+		     Eigen::MatrixBase<T4> &v12,
+		     Eigen::MatrixBase<T5> &v22)
+{
+	for (int gcx=0, c1=0,c2=0,c3=0; gcx < gcov.cols(); gcx++) {
+		for (int grx=0, r1=0,r2=0,r3=0; grx < gcov.rows(); grx++) {
+			if (filterTest(grx)) {
+				if (filterTest(gcx)) {
+					v11(r1++, c1) = gcov(grx, gcx);
+				} else {
+					v12(r2++, c2) = gcov(grx, gcx);
+				}
+			} else {
+				if (!filterTest(gcx)) {
+					v22(r3++, c3) = gcov(grx, gcx);
+				}
+			}
+		}
+		if (filterTest(gcx)) {
+			c1 += 1;
+		} else {
+			c2 += 1;
+			c3 += 1;
+		}
+	}
+}
+
+template <typename T1, typename T2, typename T3, typename T4, typename T5>
+void partitionCovarianceSet(Eigen::MatrixBase<T1> &gcov,
+			    T2 filterTest,
+			    const Eigen::MatrixBase<T3> &v11,
+			    const Eigen::MatrixBase<T4> &v12,
+			    const Eigen::MatrixBase<T5> &v22)
+{
+	for (int gcx=0, c1=0,c2=0,c3=0,c4=0; gcx < gcov.cols(); gcx++) {
+		for (int grx=0, r1=0,r2=0,r3=0,r4=0; grx < gcov.rows(); grx++) {
+			if (filterTest(grx)) {
+				if (filterTest(gcx)) {
+					gcov(grx, gcx) = v11(r1++, c1);
+				} else {
+					gcov(grx, gcx) = v12(r2++, c2);
+				}
+			} else {
+				if (!filterTest(gcx)) {
+					gcov(grx, gcx) = v22(r3++, c3);
+				} else {
+					gcov(grx, gcx) = v12(c4, r4++);
+				}
+			}
+		}
+		if (filterTest(gcx)) {
+			c1 += 1;
+			c4 += 1;
+		} else {
+			c2 += 1;
+			c3 += 1;
+		}
+	}
+}
+
+template<typename u_MatrixType, int u_UpLo = Eigen::Lower>
+class SimpCholesky : public Eigen::LDLT<u_MatrixType, u_UpLo> {
  private:
 	Eigen::MatrixXd inverse;
 
  public:
-	typedef Eigen::LDLT<_MatrixType, _UpLo> Base;
+	typedef Eigen::LDLT<u_MatrixType, u_UpLo> Base;
 
 	SimpCholesky() : Base() {};
 	template<typename InputType>
@@ -501,7 +570,7 @@ class AssertProtectStackBalanced {
 	const char *context;
 	int preDepth;
 	PROTECT_INDEX initialpix;
-	
+
 	PROTECT_INDEX getDepth() {
 		PROTECT_INDEX pix;
 		R_ProtectWithIndex(R_NilValue, &pix);
@@ -510,7 +579,7 @@ class AssertProtectStackBalanced {
 		return diff;
 	}
  public:
- 	AssertProtectStackBalanced(const char *_context) : context(_context) {
+ 	AssertProtectStackBalanced(const char *u_context) : context(u_context) {
 		R_ProtectWithIndex(R_NilValue, &initialpix);
 		Rf_unprotect(1);
 		preDepth = getDepth();
@@ -525,4 +594,23 @@ class AssertProtectStackBalanced {
 	}
 };
 
-#endif /* _OMXDEFINES_H_ */
+#define OOPS mxThrow("%s at %d: oops", __FILE__, __LINE__)
+
+inline int cast_with_NA(double val)
+{
+  if (std::isfinite(val)) return int(val);
+  return NA_INTEGER;
+}
+
+inline double cast_with_NA(int val)
+{
+  if (val == NA_INTEGER) return NA_REAL;
+  return double(val);
+}
+
+struct cstrCmp {
+	bool operator() (const char *s1, const char *s2) const
+	{ return strcmp(s1,s2) < 0; }
+};
+
+#endif /* u_OMXDEFINES_H_ */
