@@ -14,8 +14,8 @@
  * limitations under the License.
  */
 
-#ifndef _OMX_EXPECTATIONBA81_H_
-#define _OMX_EXPECTATIONBA81_H_
+#ifndef u_OMX_EXPECTATIONBA81_H_
+#define u_OMX_EXPECTATIONBA81_H_
 
 #include "omxExpectation.h"
 #include "ba81quad.h"
@@ -53,11 +53,11 @@ class BA81Expect : public omxExpectation {
 	typedef omxExpectation super;
  public:
 	virtual ~BA81Expect();
-	virtual void init();
-  virtual void connectToData();
-	virtual void compute(FitContext *fc, const char *what, const char *how);
-	virtual void populateAttr(SEXP expectation);
-	virtual omxMatrix *getComponent(const char*);
+	virtual void init() override;
+  virtual void connectToData() override;
+	virtual void compute(FitContext *fc, const char *what, const char *how) override;
+	virtual void populateAttr(SEXP expectation) override;
+	virtual omxMatrix *getComponent(const char*) override;
 
 	class ifaGroup grp;
 	int totalOutcomes() { return grp.totalOutcomes; }
@@ -73,7 +73,7 @@ class BA81Expect : public omxExpectation {
 	double freqSum;                // sum of rowFreq
 
 	// quadrature related
-	struct ba81NormalQuad &getQuad() { return grp.quad; }
+	class ba81NormalQuad &getQuad() { return grp.quad; }
 
 	// estimation related
 	omxMatrix *itemParam;
@@ -82,8 +82,8 @@ class BA81Expect : public omxExpectation {
 	bool expectedUsed;
 	int ElatentVersion;
 
-	omxMatrix *_latentMeanOut;
-	omxMatrix *_latentCovOut;
+	omxMatrix *u_latentMeanOut;
+	omxMatrix *u_latentCovOut;
 	template <typename Tmean, typename Tcov>
 	void getLatentDistribution(FitContext *fc, Eigen::MatrixBase<Tmean> &mean, Eigen::MatrixBase<Tcov> &cov);
 
@@ -105,7 +105,7 @@ class BA81Expect : public omxExpectation {
 	const char *getLatentIncompatible(BA81Expect *other);
 
 	void refreshPatternLikelihood(bool hasFreeLatent);
-	virtual void invalidateCache();
+	virtual void invalidateCache() override;
 };
 
 template <typename Tmean, typename Tcov>
@@ -113,19 +113,19 @@ void BA81Expect::getLatentDistribution(FitContext *fc, Eigen::MatrixBase<Tmean>
 {
 	int dim = grp.quad.abilities();
 	mean.derived().resize(dim);
-	if (!_latentMeanOut) {
+	if (!u_latentMeanOut) {
 		mean.setZero();
 	} else {
-		omxRecompute(_latentMeanOut, fc);
-		memcpy(mean.derived().data(), _latentMeanOut->data, sizeof(double) * dim);
+		omxRecompute(u_latentMeanOut, fc);
+		memcpy(mean.derived().data(), u_latentMeanOut->data, sizeof(double) * dim);
 	}
 
 	cov.derived().resize(dim, dim);
-	if (!_latentCovOut) {
+	if (!u_latentCovOut) {
 		cov.setIdentity();
 	} else {
-		omxRecompute(_latentCovOut, fc);
-		memcpy(cov.derived().data(), _latentCovOut->data, sizeof(double) * dim * dim);
+		omxRecompute(u_latentCovOut, fc);
+		memcpy(cov.derived().data(), u_latentCovOut->data, sizeof(double) * dim * dim);
 	}
 }
 
@@ -134,7 +134,7 @@ extern int Grpf_numModels;
 
 void ba81RefreshQuadrature(omxExpectation* oo);
 
-void ba81AggregateDistributions(std::vector<struct omxExpectation *> &expectation,
+void ba81AggregateDistributions(std::vector<class omxExpectation *> &expectation,
 				int *version, omxMatrix *meanMat, omxMatrix *covMat);
 
 #endif
